SystemOrganization addCategory: #'STON-Tests'!

TestCase subclass: #STONReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONReaderTests commentStamp: 'SvenVanCaekenberghe 1/22/2012 20:14' prior: 0!
STONReaderTests test materialization.
!

!STONReaderTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 1/15/2012 09:19'!
materialize: string
	^ (STONReader on: string readStream) next! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 10:46'!
testBoolean
	self assert: (self materialize: 'true') = true.
	self assert: (self materialize: 'false') = false! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/18/2012 21:37'!
testByteArray
	self assert: (self materialize: 'ByteArray[''010203'']') = #[1 2 3] ! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/18/2012 20:44'!
testCharacter
	self assert: (self materialize: 'Character[''A'']') == $A.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:37'!
testDate
	| date |
	date := Date year: 2012 month: 1 day: 1.
	self assert: (self materialize: 'Date[''2012-01-01'']') = date! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/19/2012 10:01'!
testDateAndTime
	| dateAndTime |
	dateAndTime := DateAndTime year: 2012 month: 1 day: 1 hour: 6 minute: 30 second: 15 offset: 1 hour.
	self assert: (self materialize: 'DateAndTime[''2012-01-01T06:30:15+01:00'']') = dateAndTime! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:45'!
testError
	self should: [ STON fromString: 'foo' ] raise: STONReaderError.
	self should: [ STON fromString: '{foo:}' ] raise: STONReaderError.
	self should: [ STON fromString: '{foo,}' ] raise: STONReaderError.
	self should: [ STON fromString: '[1,]' ] raise: STONReaderError.
	self should: [ STON fromString: '+1' ] raise: STONReaderError.
	self should: [ STON fromString: ']' ] raise: STONReaderError.
	self should: [ STON fromString: '#' ] raise: STONReaderError! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 11:05'!
testFloat
	self assert: (self materialize: '1.5') = 1.5.
	self assert: (self materialize: '-1.5') = -1.5.
	self assert: (self materialize: '0.0') = 0.0.
	self assert: (Float pi closeTo: (self materialize: '3.14149')).
	self assert: (1/3 closeTo: (self materialize: '0.333333')).
	self assert: (self materialize: '1.0e100') = (10 raisedTo: 100) asFloat.
	self assert: (self materialize: '1.0e-100') = (10 raisedTo: -100) asFloat.
	self assert: (self materialize: '-1.0e-100') = (10 raisedTo: -100) asFloat negated.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 09:21'!
testInteger
	self assert: (self materialize: '1') = 1.
	self assert: (self materialize: '-1') = -1.
	self assert: (self materialize: '0') = 0.
	self assert: (self materialize: '1234567890') = 1234567890.
	self assert: (self materialize: '-1234567890') = -1234567890! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/24/2012 21:55'!
testJsonString
	"Allow double quotes for backwards JSON compatibility"
	
	| string |
	self assert: (self materialize: '"foo"') = 'foo'.
	self assert: (self materialize: '"FOO"') = 'FOO'.
	self assert: (self materialize: '"\u00E9l\u00E8ve en Fran\u00E7ais"') = 'lve en Franais'.
	self assert: (self materialize: '"foo\rbar"') = 'foo\bar' withCRs.
	string := String withAll: { 
		$". $'. $\. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (self materialize: '"\"\''\\\t\r\n\f\b"') = string.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:19'!
testList
	| string |
	self assert: (self materialize: '[1,2,3]') = #(1 2 3).
	self assert: (self materialize: '[]') = #()! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:19'!
testMap
	| string |
	self assert: (self materialize: '{#foo:1}') = (Dictionary new at: #foo put: 1; yourself).
	self assert: (self materialize: '{}') = Dictionary new! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/25/2012 11:31'!
testNewSymbol
	| n notASymbol shouldBeSymbol |
	
	"Find a name that has not yet been interned"
	n := 0.
	[ Symbol hasInterned: (notASymbol := 'notASymbol', n printString) ifTrue: [ :symbol | symbol ] ] 
		whileTrue: [ n := n + 1 ].
	"Parsing the new, not yet interned name should create a new Symbol"
	shouldBeSymbol := self materialize: '#', notASymbol.
	self assert: (shouldBeSymbol isSymbol and: [ notASymbol = shouldBeSymbol ])
! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 10:47'!
testNil
	self assert: (self materialize: 'nil') = nil! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/27/2012 13:51'!
testNull
	self assert: (self materialize: 'null') = nil! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/17/2012 21:45'!
testObject
	self assert: (self materialize: 'Point[1,2]') = (1@2).
	self assert: (self materialize: 'Point[1.5,-0.5]') = (1.5 @ -0.5).! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 12:30'!
testOrderedCollection
	| collection |
	collection := OrderedCollection with: 1 with: 2 with: 3.
	self assert: (self materialize: 'OrderedCollection[1,2,3]') = collection.
	self assert: (self materialize: 'OrderedCollection[]') = OrderedCollection new.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/7/2012 20:30'!
testPoint
	self assert: (self materialize: 'Point[1,2]') = (1@2)! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/18/2012 21:23'!
testReferenceCycle
	| array |
	array := (self materialize: '[1,@1]').
	self assert: array isArray.
	self assert: array size = 2.
	self assert: array first = 1.
	self assert: array second == array! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/29/2012 21:52'!
testReferenceSharing
	| one array |
	one := { #one }.
	array := (self materialize: '[[#one],@2,@2]').
	self assert: array = { one. one. one }.
	self assert: array first == array second.
	self assert: array first == array third! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 11:33'!
testString
	| string |
	self assert: (self materialize: '''foo''') = 'foo'.
	self assert: (self materialize: '''FOO''') = 'FOO'.
	self assert: (self materialize: '''\u00E9l\u00E8ve en Fran\u00E7ais''') = 'lve en Franais'.
	self assert: (self materialize: '''foo\rbar''') = 'foo\bar' withCRs.
	string := String withAll: { 
		$". $'. $\. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (self materialize: '''\"\''\\\t\r\n\f\b''') = string.! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 21:38'!
testSymbol
	| string |
	self assert: (self materialize: '#''foo''') = #foo.
	self assert: (self materialize: '#foo') = #foo! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:38'!
testTime
	| time |
	time := Time hour: 6 minute: 30 second: 15.
	self assert: (self materialize: 'Time[''06:30:15'']') = time.
	time := Time hour: 6 minute: 30 second: 15 nanoSecond: 1.
	self assert: (self materialize: 'Time[''06:30:15.000000001'']') = time! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:51'!
testTimeStamp
	| timeStamp |
	timeStamp := TimeStamp year: 2012 month: 1 day: 1 hour: 6 minute: 30 second: 15 offset: 1 hour.
	self assert: (self materialize: 'TimeStamp[''2012-01-01T06:30:15+01:00'']') = timeStamp! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 16:13'!
testUser
	| user |
	(user := STONTestUser new)
		username: 'john@foo.com';
		password: 'secret1'.
	self assert: (self materialize: 'STONTestUser{#username:''john@foo.com'',#password:''secret1'',#enabled:true}') = user! !

!STONReaderTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/7/2012 20:48'!
testUser2
	| user |
	(user := STONTestUser2 new)
		username: 'john@foo.com';
		password: 'secret1'.
	self assert: (self materialize: 'STONTestUser2{#username:''john@foo.com'',#password:''secret1'',#enabled:true}') = user! !

TestCase subclass: #STONTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTests commentStamp: '<historical>' prior: 0!
STONTests tests the API offered by STON.
!

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 09:53'!
testFromString
	| object |
	object := STON listClass withAll: { 1. 0. -1. true. false. nil }.
	self assert: (STON fromString: '[1,0,-1,true,false,nil]') = object! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/12/2012 20:20'!
testPrettyPrinting
	| object |
	object := STONTestUser dummy.
	self assert: (STON fromString: (STON toStringPretty: object)) = object.
	object := STONTestDomainObject dummy.
	self assert: (STON fromString: (STON toStringPretty: object)) = object! !

!STONTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 09:53'!
testToString
	| object |
	object := STON listClass withAll: { 1. 0. -1. true. false. nil }.
	self assert: (STON toString: object) = '[1,0,-1,true,false,nil]'! !

TestCase subclass: #STONWriteReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWriteReadTests commentStamp: '<historical>' prior: 0!
STONWriteReadTests test serialization followed by materialization.!

STONWriteReadTests subclass: #STONWritePrettyPrinterReadTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWritePrettyPrinterReadTests commentStamp: '<historical>' prior: 0!
STONWritePrettyPrinterReadTests tests pretty printed serialization followed by materialization.!

!STONWritePrettyPrinterReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 1/23/2012 11:26'!
serializeAndMaterialize: object
	| serialization materialization |
	serialization := String streamContents: [ :stream |
		(STONWriter on: stream) 
			prettyPrint: true;
			nextPut: object ].
	materialization := (STONReader on: serialization readStream) next.
	self assert: object = materialization
	! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 1/22/2012 20:12'!
serializeAndMaterialize: object
	| serialization materialization |
	serialization := String streamContents: [ :stream |
		(STONWriter on: stream) nextPut: object ].
	materialization := (STONReader on: serialization readStream) next.
	self assert: object = materialization
	! !

!STONWriteReadTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 4/27/2012 14:12'!
serializeAndMaterializeJsonMode: object
	| serialization materialization |
	serialization := String streamContents: [ :stream |
		(STONWriter on: stream)
			jsonMode: true;
			nextPut: object ].
	materialization := (STONReader on: serialization readStream) next.
	self assert: object = materialization
	! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/8/2012 14:23'!
testAssociations
	| associations |
	associations := OrderedCollection new.
	1 to: 10 do: [ :each |
		associations add: each -> each printString ].
	self serializeAndMaterialize: associations! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/8/2012 14:58'!
testCharacters
	| characters |
	characters := STON listClass withAll: ($a to: $z), ($A to: $Z).
	self serializeAndMaterialize: characters! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/8/2012 20:09'!
testCollections
	| collections |
	collections := STON listClass withAll: {
		#(1 2 3).
		OrderedCollection withAll: #(1 2 3).
		Set withAll: #(1 2 3).
		IdentitySet withAll: #(1 2 3).
		Bag withAll: #(1 2 2 3).
		IdentityDictionary new at: 1 put: 1; at: 2 put: 2; yourself.
		#[1 2 3].
		#(1 2 3) asIntegerArray.
		#(1 2 3) asFloatArray }.
	self serializeAndMaterialize: collections! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:16'!
testDatesAndTimes
	| datesAndTimes |
	datesAndTimes := STON listClass withAll: { Time now. Date today. DateAndTime now. TimeStamp now }.
	self serializeAndMaterialize: datesAndTimes! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/10/2012 20:53'!
testDomainObject
	| object objects |
	object := STONTestDomainObject dummy.
	self serializeAndMaterialize: object.
	objects := STON listClass streamContents: [ :stream |
		10 timesRepeat: [ stream nextPut: STONTestDomainObject dummy ] ].
	self serializeAndMaterialize: objects.
	objects := STON mapClass new.
	10 timesRepeat: [ | newObject |
		newObject := STONTestDomainObject dummy.
		objects at: newObject integer put: newObject ].
	self serializeAndMaterialize: objects.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:17'!
testEmpty
	| empty |
	empty := STON listClass new.
	self serializeAndMaterialize: empty.
	empty := STON mapClass new.
	self serializeAndMaterialize: empty.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:16'!
testFloats
	| floats |
	floats := STON listClass withAll: ((-10 to: 10) collect: [ :each | each * Float pi ]).
	self serializeAndMaterialize: floats! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/27/2012 14:17'!
testJsonMode
	| object |
	object := STON listClass withAll: {
		Float pi.
		'Hello World'.
		true.
		nil.
		STON listClass withAll: #[ 1 2 3].
		STON mapClass new 
			at: 'x' put: 1; 
			at: 'y' put: 2; 
			yourself 
	}.
	self serializeAndMaterializeJsonMode: object! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:16'!
testPrimitives
	| primitives |
	primitives := STON listClass withAll: { true. false. nil }.
	self serializeAndMaterialize: primitives! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:17'!
testSmallIntegers
	| integers |
	integers := STON listClass withAll: (-10 to: 10).
	self serializeAndMaterialize: integers! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 12:23'!
testStrings
	| strings |
	strings := Collection allSubclasses collect: [ :each | each name asString ].
	self serializeAndMaterialize: strings! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/14/2012 17:07'!
testSymbols
	| symbols |
	self serializeAndMaterialize: #( bytes ).
	symbols := Collection allSubclasses collect: [ :each | each name ].
	self serializeAndMaterialize: symbols! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:17'!
testUser
	| user users |
	user := STONTestUser dummy.
	self serializeAndMaterialize: user.
	users := STON listClass streamContents: [ :stream |
		10 timesRepeat: [ stream nextPut: STONTestUser dummy ] ].
	self serializeAndMaterialize: users.
	users := STON mapClass new.
	10 timesRepeat: [ | newUser |
		newUser := STONTestUser dummy.
		users at: newUser username put: newUser ].
	self serializeAndMaterialize: users.! !

!STONWriteReadTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/7/2012 20:48'!
testUser2
	| user users |
	user := STONTestUser2 dummy.
	self serializeAndMaterialize: user.
	users := STON listClass streamContents: [ :stream |
		10 timesRepeat: [ stream nextPut: STONTestUser2 dummy ] ].
	self serializeAndMaterialize: users.
	users := STON mapClass new.
	10 timesRepeat: [ | newUser |
		newUser := STONTestUser2 dummy.
		users at: newUser username put: newUser ].
	self serializeAndMaterialize: users.! !

TestCase subclass: #STONWriterTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONWriterTests commentStamp: 'SvenVanCaekenberghe 1/22/2012 20:14' prior: 0!
STONWriterTests test serialization.!

!STONWriterTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 1/14/2012 15:43'!
serialize: anObject
	^ String streamContents: [ :stream |
		(STONWriter on: stream) nextPut: anObject ]! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 15:50'!
testBoolean
	self assert: (self serialize: true) = 'true'.
	self assert: (self serialize: false) = 'false'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/18/2012 21:36'!
testByteArray
	self assert: (self serialize: #[1 2 3]) = 'ByteArray[''010203'']' ! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:33'!
testDate
	| date |
	date := Date year: 2012 month: 1 day: 1.
	self assert: (self serialize: date) = 'Date[''2012-01-01'']'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/19/2012 10:00'!
testDateAndTime
	| dateAndTime |
	dateAndTime := DateAndTime year: 2012 month: 1 day: 1 hour: 6 minute: 30 second: 15 offset: 1 hour.
	self assert: (self serialize: dateAndTime) = 'DateAndTime[''2012-01-01T06:30:15+01:00'']'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/27/2012 13:48'!
testDoubleQuotedString
	| serializer string |
	serializer := [ :object | 
		String streamContents: [ :stream |
			(STONWriter on: stream)
				jsonMode: true; 
				nextPut: object ] ].
	self assert: (serializer value: 'foo') = '"foo"'.
	self assert: (serializer value: 'FOO') = '"FOO"'.
	self assert: (serializer value: 'lve en Franais') = '"\u00E9l\u00E8ve en Fran\u00E7ais"'.
	self assert: (serializer value: 'foo\bar' withCRs ) = '"foo\rbar"'.
	string := String withAll: { 
		$". $'. $\. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (serializer value: string) = '"\"\''\\\t\r\n\f\b"'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/15/2012 11:05'!
testFloat
	self assert: (self serialize: 1.5) = '1.5'.
	self assert: (self serialize: 0.0) = '0.0'.
	self assert: (self serialize: -1.5) = '-1.5'.
	self assert: ((self serialize: Float pi) beginsWith:  '3.14159').
	self assert: ((self serialize: 1/3) beginsWith:  '0.333').
	self assert: (self serialize: (10 raisedTo: 100) asFloat) = '1.0e100'.
	self assert: (self serialize: (10 raisedTo: -100) asFloat) = '1.0e-100'.
	self assert: (self serialize: (10 raisedTo: -100) asFloat negated) = '-1.0e-100'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 15:50'!
testInteger
	self assert: (self serialize: 1) = '1'.
	self assert: (self serialize: 0) = '0'.
	self assert: (self serialize: -1) = '-1'.
	self assert: (self serialize: 1234567890) = '1234567890'.
	self assert: (self serialize: -1234567890) = '-1234567890'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/14/2012 17:41'!
testIsSimpleSymbol
	self assert: (STONWriter new isSimpleSymbol: #foo).
	self assert: (STONWriter new isSimpleSymbol: #az).
	self assert: (STONWriter new isSimpleSymbol: #AZ).
	self assert: (STONWriter new isSimpleSymbol: #N0123456789).
	self assert: (STONWriter new isSimpleSymbol: #foo123).
	self assert: (STONWriter new isSimpleSymbol: #'Foo/Bar').
	self assert: (STONWriter new isSimpleSymbol: #'Foo.Bar').
	self assert: (STONWriter new isSimpleSymbol: #'Foo-Bar').
	self assert: (STONWriter new isSimpleSymbol: #'Foo_Bar').
	self assert: (STONWriter new isSimpleSymbol: #foo).
	self deny: (STONWriter new isSimpleSymbol: #'#^&$%')! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:21'!
testList
	self assert: (self serialize: (STON listClass withAll: #(1 2 3))) = '[1,2,3]'.
	self assert: (self serialize: STON listClass new) = '[]'.
	self assert: (self serialize: (STON listClass withAll: { 1. -1. 0. #foo. 'a b c'. true. false. nil })) = '[1,-1,0,#foo,''a b c'',true,false,nil]'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:20'!
testMap
	| map |
	(map := STON mapClass new)
		at: #foo put: 1;
		at: #bar put: 2.
	self assert: (self serialize: map) = '{#foo:1,#bar:2}'.
	self assert: (self serialize: STON mapClass new) = '{}'.
	map removeAll.
	map at: 'foo bar' put: #ok.
	self assert: (self serialize: map) = '{''foo bar'':#ok}'.
	map removeAll.
	map at: 123 put: 456.
	self assert: (self serialize: map) = '{123:456}'.

! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 20:20'!
testNil
	self assert: (self serialize: nil) = 'nil'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/27/2012 13:50'!
testNull
	| serializer string |
	serializer := [ :object | 
		String streamContents: [ :stream |
			(STONWriter on: stream)
				jsonMode: true; 
				nextPut: object ] ].
	self assert: (serializer value: nil) equals: 'null'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 12:28'!
testOrderedCollection
	| collection |
	collection := OrderedCollection with: 1 with: 2 with: 3.
	self assert: (self serialize: collection) = 'OrderedCollection[1,2,3]'.
	self assert: (self serialize: OrderedCollection new) = 'OrderedCollection[]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 20:35'!
testPoint
	self assert: (self serialize: 1@2) = 'Point[1,2]'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/24/2012 10:22'!
testReferenceCycle
	| array |
	array := STON listClass with: 1 with: nil.
	array at: 2 put: array.
	self assert: (self serialize: array) = '[1,@1]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/29/2012 21:53'!
testReferenceSharing
	| array one |
	one := { #one }.
	array := STON listClass with: one with: one with: one.
	self assert: (self serialize: array) = '[[#one],@2,@2]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/26/2012 21:36'!
testReferenceSharingError
	| serializer array one |
	serializer := [ :object | 
		String streamContents: [ :stream |
			(STONWriter on: stream)
				referencePolicy: #error; 
				nextPut: object ] ].
	one := { #one }.
	array := STON listClass with: one with: one with: one.
	self 
		should: [ (serializer value: array) = '[[#one],[#one],[#one]]' ] 
		raise: STONWriterError ! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/26/2012 21:36'!
testReferenceSharingIgnore
	| serializer array one |
	serializer := [ :object | 
		String streamContents: [ :stream |
			(STONWriter on: stream)
				referencePolicy: #ignore; 
				nextPut: object ] ].
	one := { #one }.
	array := STON listClass with: one with: one with: one.
	self assert: (serializer value: array) = '[[#one],[#one],[#one]]'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/27/2012 14:06'!
testRestrictedClassesInJsonMode
	| serializer string |
	serializer := [ :object | 
		String streamContents: [ :stream |
			(STONWriter on: stream)
				jsonMode: true; 
				nextPut: object ] ].
	self should: [ serializer value: 1@2 ] raise: STONWriterError.
	self should: [ serializer value: STONTestUser dummy ] raise: STONWriterError.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/14/2012 23:21'!
testString
	| string |
	self assert: (self serialize: 'foo') = '''foo'''.
	self assert: (self serialize: 'FOO') = '''FOO'''.
	self assert: (self serialize: 'lve en Franais') = '''\u00E9l\u00E8ve en Fran\u00E7ais'''.
	self assert: (self serialize: 'foo\bar' withCRs ) = '''foo\rbar'''.
	string := String withAll: { 
		$". $'. $\. Character tab. Character cr. Character lf.  Character newPage. Character backspace }.
	self assert: (self serialize: string) = '''\"\''\\\t\r\n\f\b'''.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/14/2012 17:07'!
testSymbol
	self assert: (self serialize: #foo) = '#foo'.
	self assert: (self serialize: #FOO) = '#FOO'.
	self assert: (self serialize: #bytes) = '#bytes'.
	self assert: (self serialize: #'foo.bar') = '#foo.bar'.
	self assert: (self serialize: #'foo-bar') = '#foo-bar'.
	self assert: (self serialize: #'foo_bar') = '#foo_bar'.
	self assert: (self serialize: #'foo/bar') = '#foo/bar'.
	self assert: (self serialize: #'foo bar') = '#''foo bar'''.
	self assert: (self serialize: #foo123) = '#foo123'.! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 4/27/2012 14:04'!
testSymbolAsString
	| serializer string |
	serializer := [ :object | 
		String streamContents: [ :stream |
			(STONWriter on: stream)
				jsonMode: true; 
				nextPut: object ] ].
	self assert: (serializer value: #foo) = '"foo"'.
	self assert: (serializer value: #'FOO') = '"FOO"'.
! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/23/2012 09:35'!
testTime
	| time |
	time := Time hour: 6 minute: 30 second: 15.
	self assert: (self serialize: time) = 'Time[''06:30:15'']'.
	time := Time hour: 6 minute: 30 second: 15 nanoSecond: 1.
	self assert: (self serialize: time) = 'Time[''06:30:15.000000001'']'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 1/19/2012 10:02'!
testTimeStamp
	| timeStamp |
	timeStamp := TimeStamp year: 2012 month: 1 day: 1 hour: 6 minute: 30 second: 15 offset: 1 hour.
	self assert: (self serialize: timeStamp) = 'TimeStamp[''2012-01-01T06:30:15+01:00'']'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/11/2012 13:14'!
testUser
	| user |
	(user := STONTestUser new)
		username: 'john@foo.com';
		password: 'secret1'.
	self assert: (self serialize: user) = 'TestUser{#username:''john@foo.com'',#password:''secret1'',#enabled:true}'! !

!STONWriterTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 2/11/2012 13:14'!
testUser2
	| user |
	(user := STONTestUser2 new)
		username: 'john@foo.com';
		password: 'secret1'.
	self assert: (self serialize: user) = 'TestUser2{#username:''john@foo.com'',#password:''secret1'',#enabled:true}'! !

Object subclass: #STONTestDomainObject
	instanceVariableNames: 'created modified integer float description color tags bytes boolean'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestDomainObject commentStamp: 'SvenVanCaekenberghe 2/10/2012 20:25' prior: 0!
STONTestDomainObject is used to support unit tests.

Instance Variables
	boolean:		<Boolean>
	bytes:			<ByteArray>
	color:			<Symbol>
	created:		<DateAndTime>
	description:	<String>
	float:			<Float>
	integer:		<Integer>
	modified:	<DateAndTime>
	tags:			<Array of: Symbol>!

!STONTestDomainObject class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 2/10/2012 20:51'!
dummy
	^ self new
		integer: 999999 atRandom;
		float: 999 atRandom / Float pi;
		boolean: #(true false) atRandom;
		bytes: (ByteArray streamContents: [ :out | 32 timesRepeat: [ out nextPut: 255 atRandom ] ]);
		description: (String streamContents: [ :out | 16 atRandom timesRepeat: [ out nextPutAll: 'Blah' ] ]);
		color: #(red green blue) atRandom;
		tags: { #(one two three) atRandom. #(alpha beta gamma) atRandom. #(low medium high) atRandom. };
		yourself
! !

!STONTestDomainObject class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/11/2012 13:15'!
stonName
	^ #TestDomainObject! !

!STONTestDomainObject methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
= anObject
	"Answer whether the receiver and anObject represent the same object."

	self == anObject
		ifTrue: [ ^ true ].
	self class = anObject class
		ifFalse: [ ^ false ].
	^ color = anObject color
		and: [ 
			modified = anObject modified
				and: [ 
					created = anObject created
						and: [ 
							description = anObject description
								and: [ 
									boolean = anObject boolean
										and: [ float = anObject float and: [ bytes = anObject bytes and: [ integer = anObject integer and: [ tags = anObject tags ] ] ] ] ] ] ] ]! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
boolean
	^ boolean! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
boolean: anObject
	boolean := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
bytes
	^ bytes! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
bytes: anObject
	bytes := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
color
	^ color! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
color: anObject
	color := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
created
	^ created! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
created: anObject
	created := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
description
	^ description! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
description: anObject
	description := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
float
	^ float! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
float: anObject
	float := anObject! !

!STONTestDomainObject methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
hash
	"Answer an integer value that is related to the identity of the receiver."

	^ color hash
		bitXor:
			(modified hash
				bitXor:
					(created hash
						bitXor:
							(description hash
								bitXor: (boolean hash bitXor: (float hash bitXor: (bytes hash bitXor: (integer hash bitXor: tags hash)))))))! !

!STONTestDomainObject methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 2/10/2012 20:45'!
initialize
	created := modified := DateAndTime now.! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
integer
	^ integer! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
integer: anObject
	integer := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
modified
	^ modified! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
modified: anObject
	modified := anObject! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
tags
	^ tags! !

!STONTestDomainObject methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 2/10/2012 20:44'!
tags: anObject
	tags := anObject! !

Object subclass: #STONTestUser
	instanceVariableNames: 'username password enabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestUser commentStamp: '<historical>' prior: 0!
STONTestUser is used to support unit tests.

Instance Variables
	enabled:		<Boolean>
	password:	<String>
	username:	<String>
!

!STONTestUser class methodsFor: 'instance creation' stamp: 'SvenVanCaekenberghe 1/23/2012 10:10'!
dummy
	"self dummy"
	
	| username password |
	username := String streamContents: [ :stream |
		stream << 'user'; print: 999 atRandom; << '@company'; print: 99 atRandom; << '.com' ].
	password := String streamContents: [ :stream |
		stream << 'secret'; print: 999 atRandom ].
	^ self new
		username: username;
		password: password;
		yourself! !

!STONTestUser class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/11/2012 12:45'!
stonName
	^ #TestUser! !

!STONTestUser methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:14'!
= anObject
	"Answer whether the receiver and anObject represent the same object."

	self == anObject
		ifTrue: [ ^ true ].
	self class = anObject class
		ifFalse: [ ^ false ].
	^ username = anObject username and: [ password = anObject password and: [ enabled = anObject enabled ] ]! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
enabled
	^ enabled! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
enabled: anObject
	enabled := anObject! !

!STONTestUser methodsFor: 'comparing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:14'!
hash
	"Answer an integer value that is related to the identity of the receiver."

	^ username hash bitXor: (password hash bitXor: enabled hash)! !

!STONTestUser methodsFor: 'initialize-release' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
initialize 
	super initialize.
	enabled := true! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
password
	^ password! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
password: anObject
	password := anObject! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
username
	^ username! !

!STONTestUser methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 1/23/2012 10:03'!
username: anObject
	username := anObject! !

STONTestUser subclass: #STONTestUser2
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'STON-Tests'!

!STONTestUser2 commentStamp: 'SvenVanCaekenberghe 2/10/2012 20:20' prior: 0!
STONTestUser2 extends STONTestUser with explicit implementations of #fromSton: and #stonOn:!

!STONTestUser2 class methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/11/2012 13:15'!
stonName
	^ #TestUser2! !

!STONTestUser2 methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/12/2012 14:32'!
fromSton: stonReader
	stonReader parseMapDo: [ :key :value |
		key = #username ifTrue: [ username := value ].
		key = #password ifTrue: [ password := value ].
		key = #enabled ifTrue: [ enabled := value ] ]
	! !

!STONTestUser2 methodsFor: 'ston-core' stamp: 'SvenVanCaekenberghe 2/7/2012 20:49'!
stonOn: stonWriter	
	stonWriter writeObject: self streamMap: [ :dictionary |
		dictionary
			at: #username put: username;
			at: #password put: password;
			at: #enabled put: enabled ]! !
